cusum_control(
x,
target = NULL,
std_dev = NULL,
desired_shift = 1,
k = 0.5,
h = 4
)
Arguments
x
input vector
target
target value for comparison, the mean of x will be used if missing
std_dev
Defaults to the screened moving range of x.
A known or desired value for standard deviation can be supplied instead.
desired_shift
how many standard deviations do you want to detect?
This value is typically between 0.5 to 1. Defaults to 1.
k
allowable slack - defaults to half the standard deviation multiplied by desired shift
h
action limits - usually between 4 and 5, defaults to 4.
The standard deviation is multiplied by this value to determine the upper and lower limits on the chart
Value
data.frame showing original inputs and calculated control limits