a numeric vector from which to calculate the cumulative sum statistics
target
value to compare each element of x to. If not provided, the mean of
x will be calculated and used as a target value
Value
a dataframe with the original values, target, the variance, the cumulative sum of the variance, and the cumulative sum centered on the target value. This centering is achieved by adding the target value to the cumulative sum.