powered by
cusum_single_median
cusum_single_median(x, target = NULL)
a numeric vector from which to calculate the cumulative sum statistics
value to compare each element of x to. If not provided, the median value of x will be calculated and used as a target value
a vector of the cumulative sum statistic, centred on the target value
# NOT RUN { test_vec <- c(0.175, 0.152, 0.15, 0.207, 0.136, 0.212, 0.166) cusum_single_median(test_vec) # }
Run the code above in your browser using DataLab